@@ -4,7 +4,7 @@
     rust_2018_idioms,
     unreachable_pub
 )]
-#![deny(broken_intra_doc_links)]
+#![deny(rustdoc::broken_intra_doc_links)]
 #![forbid(unsafe_code)]
 
 //! Collections with a statically known minimum size.
@@ -15,7 +15,7 @@
 
 use std::{
     cmp,
-    convert::TryFrom,
+    convert::{TryFrom, TryInto},
     fmt,
     ops::{Deref, DerefMut, Index, IndexMut},
     slice::{Iter as SliceIter, IterMut as SliceIterMut, SliceIndex},
@@ -123,6 +123,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
     /// let v: Vec<_> = v.into_inner();
     /// assert_eq!(v, vec![1, 2, 3]);
     /// ```
+    #[must_use]
     pub fn into_inner(self) -> Vec<T> {
         self.0
     }
@@ -311,7 +312,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
         self.0.insert(index, element);
     }
 
-    /// Remove and and return the element at the given index from the collection.
+    /// Remove and return the element at the given index from the collection.
     ///
     /// This will shift all elements after `index` to the left.
     ///
@@ -335,6 +336,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
     /// // This will panic, since the minimum size is 2:
     /// v.remove(1);
     /// ```
+    #[track_caller]
     pub fn remove(&mut self, index: usize) -> T {
         if index >= self.len() {
             panic!(
@@ -354,7 +356,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
         self.0.remove(index)
     }
 
-    /// Remove and and return the element at the given index from the collection.
+    /// Remove and return the element at the given index from the collection.
     ///
     /// This will replace the empty slot left by the removal with the last element in the
     /// collection. This does not preserve ordering, but is O(1).
@@ -379,6 +381,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
     /// // This will panic, since the minimum size is 2:
     /// v.swap_remove(1);
     /// ```
+    #[track_caller]
     pub fn swap_remove(&mut self, index: usize) -> T {
         if index >= self.len() {
             panic!(
@@ -482,7 +485,7 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
         }
     }
 
-    /// Try to change the mininum size of the collection to `NEW`.
+    /// Try to change the minimum size of the collection to `NEW`.
     ///
     /// This will inspect the current **runtime** length of the collection. If it is greater than
     /// or equal to `NEW`, a successful [`Result`] containing a collection with the updated minimum
@@ -511,10 +514,38 @@ impl<T, const MINIMUM_SIZE: usize> MinSizedVec<T, MINIMUM_SIZE> {
         self.0.capacity()
     }
 
-    /// Returs the entire collection as a slice.
+    /// Returns the entire collection as a slice.
     fn as_slice(&self) -> &[T] {
         self
     }
+
+    /// Returns a fixed-size array of the start of the collection.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use minsize::MinSizedVec;
+    /// let v: MinSizedVec<_, 2> = MinSizedVec::new(vec![1, 2, 3]).unwrap();
+    ///
+    /// assert_eq!(*v.guaranteed_head(), [1, 2]);
+    /// ```
+    pub fn guaranteed_head(&self) -> &[T; MINIMUM_SIZE] {
+        self.0[..MINIMUM_SIZE].try_into().unwrap()
+    }
+
+    /// Returns a fixed-size array of the end of the collection.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use minsize::MinSizedVec;
+    /// let v: MinSizedVec<_, 2> = MinSizedVec::new(vec![1, 2, 3]).unwrap();
+    ///
+    /// assert_eq!(*v.guaranteed_tail(), [2, 3]);
+    /// ```
+    pub fn guaranteed_tail(&self) -> &[T; MINIMUM_SIZE] {
+        self.0[(self.len() - MINIMUM_SIZE)..].try_into().unwrap()
+    }
 }
 
 /// **NOTE**: This impl block contains methods that are available if the minimum size is greater
